package com.tuoheng.admin.controller;

import com.tuoheng.admin.entity.Inspection;
import com.tuoheng.admin.request.inspection.QueryInspectionPageListRequest;
import com.tuoheng.admin.service.inspection.IInspectionService;
import com.tuoheng.common.core.utils.JsonResult;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * 巡检任务前端控制器
 *
 * @author wanjing
 * @team tuoheng
 * @date 2022-11-16
 */
@Slf4j
@RestController
@RequestMapping("/inspection")
public class InspectionController {

    @Autowired
    private IInspectionService iInspectionService;

    /**
     * 查询巡检任务分页列表
     */
    @GetMapping("/page/list")
    public JsonResult list(QueryInspectionPageListRequest request) {
        log.info("进入查询巡检任务分页列表");
        return iInspectionService.selectPageList(request);
    }

    /**
     * 获取巡检任务详细信息
     */
    @GetMapping(value = "/{id}")
    public JsonResult getInfo(QueryInspectionPageListRequest request) {
        return iInspectionService.selectOneById(request);
    }

    /**
     * 新增巡检任务
     */
    @PostMapping
    public JsonResult add(@RequestBody Inspection inspection) {
        return iInspectionService.insert(inspection);
    }

    /**
     * 修改巡检任务
     */
    @PutMapping
    public JsonResult edit(@RequestBody Inspection inspection) {
        return iInspectionService.update(inspection);
    }

    /**
     * 删除巡检任务
     */
    @DeleteMapping("/{ids}")
    public JsonResult delete(@PathVariable String[] ids) {
        return iInspectionService.deleteByIds(ids);
    }
}
