package com.tuoheng.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.tuoheng.admin.entity.RoadInformation;
import com.tuoheng.admin.entity.Section;
import com.tuoheng.admin.entity.User;
import com.tuoheng.admin.mapper.RoadInformationMapper;
import com.tuoheng.admin.mapper.SectionMapper;
import com.tuoheng.admin.query.RoadInformationQuery;
import com.tuoheng.admin.service.RoadInformationService;
import com.tuoheng.admin.service.road.query.QueryRoadListByDeptIdService;
import com.tuoheng.common.core.common.BaseServiceImpl;
import com.tuoheng.common.core.enums.ServiceExceptionEnum;
import com.tuoheng.common.core.utils.DateUtils;
import com.tuoheng.common.core.utils.JsonResult;
import com.tuoheng.common.core.utils.StringUtils;
import com.tuoheng.common.core.utils.ThreadLocalUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * @Author ChengWang
 * @Date 2022/11/17
 */
@Service
public class RoadInformationServiceImpl extends BaseServiceImpl<RoadInformationMapper, RoadInformation> implements RoadInformationService {

    @Autowired
    private RoadInformationMapper roadInformationMapper;

    @Autowired
    private SectionMapper sectionMapper;

    @Autowired
    private QueryRoadListByDeptIdService queryRoadListByDeptIdService;

    @Override
    public JsonResult queryPage(RoadInformationQuery query) {
        if (query.getLimit() == null && query.getPage() == null) {
            return JsonResult.error(ServiceExceptionEnum.PARAMETER_IS_NULL);
        }
        //获取登录人信息id
        //Long userId = SecurityUserUtils.getLoginUser().getUserId();
        //获取分页数据
        IPage<RoadInformation> page = new Page<>(query.getPage(), query.getLimit());
        IPage<RoadInformation> pageData = roadInformationMapper.selectPage(page, Wrappers.<RoadInformation>lambdaQuery()
                .eq(RoadInformation::getMark, 1)
                .eq(RoadInformation::getTenantId, 0)
                .orderByDesc(RoadInformation::getCreateTime));
        List<RoadInformation> records = pageData.getRecords();
        List<RoadInformation> list = new ArrayList<>();
        for (RoadInformation record : records) {
            //判断公路关联路段信息
            RoadRelation(record);
            list.add(record);
        }
        pageData.setRecords(list);

        return JsonResult.success(pageData);
    }

    @Override
    public JsonResult getListInfo(RoadInformationQuery query) {
        //当前租户下所有公路信息
        List<RoadInformation> roadInformationList = roadInformationMapper.selectList(new LambdaQueryWrapper<RoadInformation>()
                .eq(RoadInformation::getMark, 1)
                .eq(RoadInformation::getTenantId, 0));
        List<RoadInformation> list = new ArrayList<>();
        for (RoadInformation roadInformation : roadInformationList) {
            RoadRelation(roadInformation);
            list.add(roadInformation);
        }

        return JsonResult.success(list);
    }

    /**
     * 根据部门id获取该部门下公路列表
     * @param deptId
     * @return
     */
    @Override
    public JsonResult getListByDeptId(String deptId) {
        return queryRoadListByDeptIdService.getRoadList(deptId);
    }

    @Override
    public JsonResult editInfo(RoadInformation entity) {
//        User user = (User) ThreadLocalUtil.get();
//        if (StringUtils.isNull(user)) {
//            return JsonResult.error("获取不到用户信息");
//        }
        if (StringUtils.isEmpty(entity.getId())) {
            //新增
            entity.setCreateUser("cw");
            entity.setCreateTime(DateUtils.now());
        } else {
            //更新
            entity.setUpdateUser("cw");
            entity.setUpdateTime(DateUtils.now());
        }
        super.edit(entity);

        return JsonResult.success();
    }

//    @Override
//    public JsonResult deleteRoadByIds(String[] ids) {
//        if (StringUtils.isNull(ids)) {
//            return JsonResult.error("公路ID不能为空");
//        }
//        for (String id : ids) {
//            RoadInformation roadInformation = roadInformationMapper.selectById(id);
//            //判断公路是否关联路段
//            List<Section> sectionList = sectionMapper.selectList(new LambdaQueryWrapper<Section>()
//                    .eq(Section::getMark, 1)
//                    .eq(Section::getTenantId, 1)
//                    .eq(Section::getRoadId, roadInformation.getId()));
//            if (StringUtils.isEmpty(sectionList)) {
//                super.deleteById(id);
//            }
//            //公路关联路段不为空,删除公路对应的路段
//            for (Section section : sectionList) {
//                LambdaUpdateWrapper<Section> qw = new LambdaUpdateWrapper<>();
//                qw.set(Section::getMark, 0);
//                qw.eq(Section::getId, section.getId());
//                int update = sectionMapper.update(section, qw);
//                if (update <= 0) {
//                    return JsonResult.error();
//                }
//            }
//        }
//        return JsonResult.success("删除成功");
//    }

    /**
     * 判断公路是否关联路段
     *
     * @param roadInformation
     */
    private void RoadRelation(RoadInformation roadInformation) {
        List<Section> sectionList = sectionMapper.selectList(new LambdaQueryWrapper<Section>()
                .eq(Section::getMark, 1)
                .eq(Section::getTenantId, 0)
                .eq(Section::getRoadId, roadInformation.getId()));
        if (StringUtils.isNotEmpty(sectionList)) {
            //公路绑定路段，关联字段设置为true
            roadInformation.setRelation(true);
        } else {
            //公路未绑定路段，关联字段设置为false
            roadInformation.setRelation(false);
        }
    }
}
