package com.tuoheng.admin.service.inspection;

import com.tuoheng.admin.entity.Inspection;
import com.tuoheng.admin.mapper.InspectionMapper;
import com.tuoheng.admin.request.inspection.QueryInspectionPageListRequest;
import com.tuoheng.admin.service.inspection.query.QueryInspectionPageListService;
import com.tuoheng.common.core.utils.JsonResult;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 巡检任务Service业务层处理
 *
 * @team tuoheng
 * @author wanjing
 * @date 2022-11-16
 */
@Slf4j
@Service
public class InspectionServiceImpl implements IInspectionService {
    @Autowired
    private InspectionMapper inspectionMapper;

    @Autowired
    QueryInspectionPageListService queryInspectionPageListService;

    /**
     * 查询巡检任务分页列表
     *
     * @param queryInspectionRequest 巡检任务查询实体
     * @return
     */
    @Override
    public JsonResult selectPageList(QueryInspectionPageListRequest queryInspectionRequest) {
        return queryInspectionPageListService.getPageList(queryInspectionRequest);
    }

    /**
     * 查询巡检任务
     * 
     * @param request 巡检任务查询实体
     * @return 巡检任务
     */
    @Override
    public JsonResult selectOneById(QueryInspectionPageListRequest request) {
//        request.setTenantId(ShiroUtils.getTenantId());

        Inspection inspection = inspectionMapper.selectOneById(request);

//        if (ObjectUtil.isNull(inspection)) {
//            throw new ServiceException(ServiceExceptionEnum.GET_NO_DATA);
//        }

        return JsonResult.success(inspection);
    }

    /**
     * 查询巡检任务列表
     * 
     * @param request 巡检任务查询实体
     * @return 巡检任务
     */
    @Override
    public JsonResult selectList(QueryInspectionPageListRequest request) {
        log.info("进入查询巡检任务列表业务");
//        Page<Inspection> page = new Page<>(request.getPage(), request.getLimit());
//        request.setUserId(ShiroUtils.getUserId());
//        request.setTenantId(ShiroUtils.getTenantId());

//        List<Inspection> list = inspectionMapper.selectList(page, request);

        return JsonResult.success();
    }

    /**
     * 新增巡检任务
     * 
     * @param inspection 巡检任务
     * @return 结果
     */
    @Override
    public JsonResult insert(Inspection inspection) {
        inspectionMapper.insert(inspection);

        return JsonResult.success();
    }

    /**
     * 修改巡检任务
     * 
     * @param inspection 巡检任务
     * @return 结果
     */
    @Override
    public JsonResult update(Inspection inspection) {
        inspectionMapper.update(inspection);

        return JsonResult.success();
    }

    /**
     * 批量删除巡检任务
     * 
     * @param ids 需要删除的巡检任务主键
     * @return 结果
     */
    @Override
    public JsonResult deleteByIds(String[] ids) {
        inspectionMapper.deleteByIds(ids);

        return JsonResult.success();

    }

    /**
     * 删除巡检任务信息
     * 
     * @param id 巡检任务主键
     * @return 结果
     */
    @Override
    public JsonResult deleteById(String id) {
        inspectionMapper.deleteById(id);

        return JsonResult.success();
    }
}
